@@ -20,7 +20,7 @@ viewsize(int *ln, int *col)
 {
 	struct winsize ws;
 
-	if (ioctl(1, TIOCGWINSZ, &ws) < 0) {
+	if (ioctl(1, TIOCGWINSZ, &ws) == -1) {
 		die("Could not get terminal resolution: %s",
 		    strerror(errno));
 	}
@@ -100,10 +100,10 @@ printstatus(Item *item, char c)
 
 	fmt = (strcmp(item->port, "70") && strcmp(item->port, "gopher")) ?
 	      "%1$3lld%%%*2$3$c %4$s:%8$s/%5$c%6$s [%7$c]: " :
-              "%3lld%%%*c %s/%c%s [%c]: ";
+              "%3lld%% %s/%c%s [%c]: ";
 	if (snprintf(bufout, sizeof(bufout), fmt,
 	             (printoff + lines-1 >= nitems) ? 100 :
-	             (printoff + lines) * 100 / nitems, ndigits(nitems)+2, '|',
+	             (printoff + lines) * 100 / nitems,
 	             item->host, item->type, item->selector, c, item->port)
 	    >= sizeof(bufout))
 		bufout[sizeof(bufout)-1] = '\0';
@@ -126,7 +126,7 @@ uiprompt(char *fmt, ...)
 	mbsprint(bufout, columns);
 	fflush(stdout);
 
-	if ((r = getline(&input, &n, stdin)) < 0) {
+	if ((r = getline(&input, &n, stdin)) == -1) {
 		clearerr(stdin);
 		clear(&input);
 		putchar('\n');
